"""
Systematic module for filesystem and path handling
"""

# flake8: noqa: F401
from .tree import Tree
